summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorChristian Pointner <equinox@helsinki.at>2016-01-13 13:41:28 (GMT)
committerChristian Pointner <equinox@helsinki.at>2016-01-13 13:41:28 (GMT)
commitb2398fd830443fa2930de0605d153b8a1264be95 (patch)
treef7c9c35a3c340b424919cd705ebd3d54b5da8109 /src
parentd95d4579b749b7fd3729099e8751ea9584ffdea0 (diff)
renamed rhrdlibrary to rhlibrary
Diffstat (limited to 'src')
-rw-r--r--src/rhlibrary/main.go (renamed from src/rhrdlibrary/main.go)16
-rw-r--r--src/rhlibrary/player.go (renamed from src/rhrdlibrary/player.go)10
2 files changed, 13 insertions, 13 deletions
diff --git a/src/rhrdlibrary/player.go b/src/rhlibrary/player.go
index 3463190..3e4211c 100644
--- a/src/rhrdlibrary/player.go
+++ b/src/rhlibrary/player.go
@@ -1,25 +1,25 @@
//
-// rhrdlibrary
+// rhlibrary
//
// The Radio Helsinki Rivendell Library
//
//
// Copyright (C) 2016 Christian Pointner <equinox@helsinki.at>
//
-// This file is part of rhrdlibrary.
+// This file is part of rhlibrary.
//
-// rhrdlibrary is free software: you can redistribute it and/or modify
+// rhlibrary is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
-// rhrdlibrary is distributed in the hope that it will be useful,
+// rhlibrary is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
-// along with rhrdlibrary. If not, see <http://www.gnu.org/licenses/>.
+// along with rhlibrary. If not, see <http://www.gnu.org/licenses/>.
//
package main
diff --git a/src/rhrdlibrary/main.go b/src/rhlibrary/main.go
index 4209b8a..85e5b8a 100644
--- a/src/rhrdlibrary/main.go
+++ b/src/rhlibrary/main.go
@@ -1,25 +1,25 @@
//
-// rhrdlibrary
+// rhlibrary
//
// The Radio Helsinki Rivendell Library
//
//
// Copyright (C) 2016 Christian Pointner <equinox@helsinki.at>
//
// This file is part of rhrdlibrary.
//
// rhrdlibrary is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// rhrdlibrary is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
-// along with rhrdlibrary. If not, see <http://www.gnu.org/licenses/>.
+// along with rhlibrary. If not, see <http://www.gnu.org/licenses/>.
//
package main
@@ -36,8 +36,8 @@ import (
)
var (
- rhl = log.New(os.Stderr, "[rhrdlibrary]\t", log.LstdFlags)
- rhdl = log.New(ioutil.Discard, "[rhrdlibrary-dbg]\t", log.LstdFlags)
+ rhl = log.New(os.Stderr, "[rhlibrary]\t", log.LstdFlags)
+ rhdl = log.New(ioutil.Discard, "[rhlibrary-dbg]\t", log.LstdFlags)
)
func init() {
@@ -83,7 +83,7 @@ func main() {
}
defer db.Cleanup()
- player, _ := NewPlayer("/home/equinox/helsinki/rivenhell/contrib/rhrdlibrary/snd")
+ player, _ := NewPlayer("/home/equinox/helsinki/rivenhell/contrib/rhlibrary/snd")
var wg sync.WaitGroup
@@ -1,25 +1,25 @@
// Copyright (C) 2016 Christian Pointner <equinox@helsinki.at>
//
-// This file is part of rhrdlibrary.
+// This file is part of rhlibrary.
//
@@ -1,25 +1,25 @@
//
-// rhrdlibrary is free software: you can redistribute it and/or modify
+// rhlibrary is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
@@ -1,25 +1,25 @@
// any later version.
//
-// rhrdlibrary is distributed in the hope that it will be useful,
+// rhlibrary is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the